# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/notify/notification.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/notify/notification.proto\x12\reolymp.notify\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x02\n\x0cNotification\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04read\x18\x02 \x01(\x08\x12\r\n\x05topic\x18\n \x01(\t\x12?\n\nparameters\x18\x0b \x03(\x0b\x32+.eolymp.notify.Notification.ParametersEntry\x12.\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07sent_at\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07read_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/notify;notifyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.notify.notification_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/notify;notify'
  _NOTIFICATION_PARAMETERSENTRY._options = None
  _NOTIFICATION_PARAMETERSENTRY._serialized_options = b'8\001'
  _NOTIFICATION._serialized_start=85
  _NOTIFICATION._serialized_end=394
  _NOTIFICATION_PARAMETERSENTRY._serialized_start=345
  _NOTIFICATION_PARAMETERSENTRY._serialized_end=394
# @@protoc_insertion_point(module_scope)
