# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/linked_account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/community/linked_account.proto\x12\x10\x65olymp.community\"\x96\x01\n\rLinkedAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.eolymp.community.LinkedAccount.Type\x12\x0e\n\x06issuer\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\"$\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\n\n\x06GOOGLE\x10\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.linked_account_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _LINKEDACCOUNT._serialized_start=60
  _LINKEDACCOUNT._serialized_end=210
  _LINKEDACCOUNT_TYPE._serialized_start=174
  _LINKEDACCOUNT_TYPE._serialized_end=210
# @@protoc_insertion_point(module_scope)
