# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ecm/node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x65olymp/ecm/node.proto\x12\neolymp.ecm\"\x8f\x01\n\x04Node\x12\x0c\n\x04type\x18\x01 \x01(\t\x12(\n\x04\x61ttr\x18\x02 \x03(\x0b\x32\x1a.eolymp.ecm.Node.AttrEntry\x12\"\n\x08\x63hildren\x18\x03 \x03(\x0b\x32\x10.eolymp.ecm.Node\x1a+\n\tAttrEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42)Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecmb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ecm.node_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecm'
  _NODE_ATTRENTRY._options = None
  _NODE_ATTRENTRY._serialized_options = b'8\001'
  _NODE._serialized_start=38
  _NODE._serialized_end=181
  _NODE_ATTRENTRY._serialized_start=138
  _NODE_ATTRENTRY._serialized_end=181
# @@protoc_insertion_point(module_scope)
