# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/auth/claims.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/auth/claims.proto\x12\x0b\x65olymp.auth\"\xfd\x01\n\x06\x43laims\x12\x0b\n\x02id\x18\xe8\x07 \x01(\t\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\n \x01(\t\x12\x16\n\x0e\x65mail_verified\x18\x0b \x01(\x08\x12\x0c\n\x04name\x18\x1e \x01(\t\x12\x10\n\x08nickname\x18\x1f \x01(\t\x12\x0f\n\x07picture\x18( \x01(\t\x12\x0e\n\x06locale\x18\x32 \x01(\t\x12\x10\n\x08timezone\x18\x33 \x01(\t\x12\x10\n\x08\x62irthday\x18< \x01(\t\x12\r\n\x05minor\x18= \x01(\x08\x12\x0f\n\x07\x63ountry\x18\x46 \x01(\t\x12\x19\n\x11preferred_runtime\x18Z \x01(\tB+Z)github.com/eolymp/go-sdk/eolymp/auth;authb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.auth.claims_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/auth;auth'
  _CLAIMS._serialized_start=42
  _CLAIMS._serialized_end=295
# @@protoc_insertion_point(module_scope)
